@@ -25,10 +25,10 @@ def run(file: Optional[Path] = None):
 @click.command(help="""Play the specified sound file while data is passed in through standard input and passed through standard output.""")
 @click.option('-s', '--sound_path', required=False,
   type=click.Path(exists=True), help="Path to sound to play.")
-@click.option('-i', '--ignore', required=False,
-  is_flag=True, default=False, help="Suppress warnings.")
-def cmd(sound_path: Optional[str], ignore: bool):
-  with using_path(sound_path, ignore) as path:
+@click.option('-w', '--warn', required=False,
+  is_flag=True, default=False, help="Show warnings.")
+def cmd(sound_path: Optional[str], warn: bool):
+  with using_path(sound_path, warn) as path:
     run(path)
 
 
